from django.apps import AppConfig


class FinanceConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'xj_finance'
    verbose_name = 'Ⅳ 资金系统'
    sort = 4
